/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes;

import java.util.Timer;

import org.ow2.petals.probes.api.ProbesFactory;
import org.ow2.petals.probes.api.probes.CounterProbe;
import org.ow2.petals.probes.api.probes.DurationProbe;
import org.ow2.petals.probes.api.probes.GaugeProbe;
import org.ow2.petals.probes.api.sensor.GaugeSensor;
import org.ow2.petals.probes.api.sensor.detector.GaugeDefectDetector;
import org.ow2.petals.probes.impl.CounterProbeImpl;
import org.ow2.petals.probes.impl.DurationProbeImpl;
import org.ow2.petals.probes.impl.GaugeProbeImpl;

/**
 * The default implementation of petals probes.
 * 
 * @param <T>
 *            The type of measured values (internal value type).
 * @param <S>
 *            The type of value to return to client probe (external value type).
 * 
 * @author Christophe DENEUX (Linagora)
 */
public class ProbesFactoryImpl<T extends Comparable<T>, S> implements ProbesFactory<T, S> {

    @Override
    public CounterProbe createCounterProbe() {
        return new CounterProbeImpl();
    }

    @Override
    public GaugeProbe<T, S> createGaugeProbe(GaugeSensor<T, S> sensor) {
        return new GaugeProbeImpl<T, S>(sensor, null);
    }

    @Override
    public GaugeProbe<T, S> createGaugeProbe(GaugeSensor<T, S> sensor,
            final GaugeDefectDetector<T> defectDetector) {
        return new GaugeProbeImpl<T, S>(sensor, defectDetector);
    }

    @Override
    public DurationProbe createDurationProbe(final Timer timer, final long samplePeriod)
            throws IllegalArgumentException {
        return new DurationProbeImpl(timer, samplePeriod);
    }
}
