/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.impl.macro.detector;

import java.util.concurrent.ThreadPoolExecutor;

import org.ow2.petals.probes.api.sensor.detector.DefectCreator;
import org.ow2.petals.probes.api.sensor.detector.GaugeDefectDetector;

/**
 * Defect detector attached to the allocated threads of the thread pool. A
 * defect is created when no more threads is available in the thread pool.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class ThreadPoolAllocatedThreadsDefectDetector implements GaugeDefectDetector<Long> {

    /**
     * The factory creating the defect about the thread pool exhausted.
     */
    private final DefectCreator threadPoolExhaustedDefectCreator;

    /**
     * The thread pool
     */
    private ThreadPoolExecutor threadPool = null;

    /**
     * 
     * @param threadPoolExhaustedDefectCreator
     *            The factory creating and sending the defect about the thread
     *            pool exhausted
     */
    public ThreadPoolAllocatedThreadsDefectDetector(
            final DefectCreator threadPoolExhaustedDefectCreator) {
        this.threadPoolExhaustedDefectCreator = threadPoolExhaustedDefectCreator;
    }

    public final void setThreadPool(final ThreadPoolExecutor threadPool) {
        this.threadPool = threadPool;
    }

    @Override
    public void detect(final Long instantValue) {
        if (this.threadPool.getMaximumPoolSize() - instantValue == 0) {
            // No more threads is available
            this.threadPoolExhaustedDefectCreator.createAndSend();
        }

    }
}