/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.key;

import org.ow2.petals.probes.api.enums.ExecutionStatus;
import org.ow2.petals.probes.api.key.ProbeKey;

/**
 * A test key object with a changeable execution status
 * 
 * @author Christophe DENEUX (PetalsLink)
 *
 */
public class ProbeTestExecutionStatusKey implements ProbeKey {
	
	private final String name;
	
	private ExecutionStatus status;
	
	public ProbeTestExecutionStatusKey(final String name, final ExecutionStatus executionStatus) {
		this.name = name;
		this.status = executionStatus;
	}
	
	@Override
	public String[] toStringArray() {
		return new String[] { this.name, this.status.toString() };
	}
	
    @Override
    public String toReadableString() {
        return this.name + ", " + this.status;
    }

    public String getName() {
		return this.name;
	}

	// Generated by Eclipse
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((status == null) ? 0 : status.hashCode());
		return result;
	}

	// Generated by Eclipse
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		ProbeTestExecutionStatusKey other = (ProbeTestExecutionStatusKey) obj;
		if (name == null) {
			if (other.name != null)
				return false;
		} else if (!name.equals(other.name))
			return false;
		if (status != other.status)
			return false;
		return true;
	}
	
}